@@ -398,10 +398,18 @@ Repository: {}
         ));
     } else {
         let shell = match std::env::var("SHELL") {
-            Ok(shell) => shell,
+            Ok(s) => s,
             Err(_) => "/bin/sh".to_string(),
         };
 
+        let home;
+        let mut homeargs = Vec::new();
+        if let Ok(s) = std::env::var("HOME") {
+            home = format!("whitelist/write+{}/***", s);
+            homeargs.push("-m");
+            homeargs.push(&home);
+        }
+
         let mut paludis = Vec::new();
         for magic in PALUDIS.split('\n').filter(|&magic| !magic.is_empty()) {
             paludis.push("-m");
@@ -418,6 +426,7 @@ Repository: {}
 
         let mut child = Command::new("sydbox")
             .args(&paludis)
+            .args(&homeargs)
             .args(&rcargs)
             .arg("--")
             .arg(shell)
